@@ -1,25 +1,47 @@
 /****************************************************************************
 ** Meta object code from reading C++ file 'ddlineedit.h'
 **
-** Created by: The Qt Meta Object Compiler version 63 (Qt 4.8.7)
+** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
 
-#include "../../src/ttfautohint-1.8.1/frontend/ddlineedit.h"
+#include "../../src/ttfautohint-1.8.3/frontend/ddlineedit.h"
+#include <QtCore/qbytearray.h>
+#include <QtCore/qmetatype.h>
 #if !defined(Q_MOC_OUTPUT_REVISION)
 #error "The header file 'ddlineedit.h' doesn't include <QObject>."
-#elif Q_MOC_OUTPUT_REVISION != 63
-#error "This file was generated using the moc from 4.8.7. It"
+#elif Q_MOC_OUTPUT_REVISION != 67
+#error "This file was generated using the moc from 5.9.4. It"
 #error "cannot be used with the include files from this version of Qt."
 #error "(The moc has changed too much.)"
 #endif
 
 QT_BEGIN_MOC_NAMESPACE
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
+struct qt_meta_stringdata_Drag_Drop_Line_Edit_t {
+    QByteArrayData data[1];
+    char stringdata0[20];
+};
+#define QT_MOC_LITERAL(idx, ofs, len) \
+    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
+    qptrdiff(offsetof(qt_meta_stringdata_Drag_Drop_Line_Edit_t, stringdata0) + ofs \
+        - idx * sizeof(QByteArrayData)) \
+    )
+static const qt_meta_stringdata_Drag_Drop_Line_Edit_t qt_meta_stringdata_Drag_Drop_Line_Edit = {
+    {
+QT_MOC_LITERAL(0, 0, 19) // "Drag_Drop_Line_Edit"
+
+    },
+    "Drag_Drop_Line_Edit"
+};
+#undef QT_MOC_LITERAL
+
 static const uint qt_meta_data_Drag_Drop_Line_Edit[] = {
 
  // content:
-       6,       // revision
+       7,       // revision
        0,       // classname
        0,    0, // classinfo
        0,    0, // methods
@@ -32,10 +54,6 @@ static const uint qt_meta_data_Drag_Drop_Line_Edit[] = {
        0        // eod
 };
 
-static const char qt_meta_stringdata_Drag_Drop_Line_Edit[] = {
-    "Drag_Drop_Line_Edit\0"
-};
-
 void Drag_Drop_Line_Edit::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
 {
     Q_UNUSED(_o);
@@ -44,37 +62,29 @@ void Drag_Drop_Line_Edit::qt_static_metacall(QObject *_o, QMetaObject::Call _c,
     Q_UNUSED(_a);
 }
 
-const QMetaObjectExtraData Drag_Drop_Line_Edit::staticMetaObjectExtraData = {
-    0,  qt_static_metacall 
-};
-
 const QMetaObject Drag_Drop_Line_Edit::staticMetaObject = {
-    { &Tooltip_Line_Edit::staticMetaObject, qt_meta_stringdata_Drag_Drop_Line_Edit,
-      qt_meta_data_Drag_Drop_Line_Edit, &staticMetaObjectExtraData }
+    { &Tooltip_Line_Edit::staticMetaObject, qt_meta_stringdata_Drag_Drop_Line_Edit.data,
+      qt_meta_data_Drag_Drop_Line_Edit,  qt_static_metacall, nullptr, nullptr}
 };
 
-#ifdef Q_NO_DATA_RELOCATION
-const QMetaObject &Drag_Drop_Line_Edit::getStaticMetaObject() { return staticMetaObject; }
-#endif //Q_NO_DATA_RELOCATION
 
 const QMetaObject *Drag_Drop_Line_Edit::metaObject() const
 {
-    return QObject::d_ptr->metaObject ? QObject::d_ptr->metaObject : &staticMetaObject;
+    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
 }
 
 void *Drag_Drop_Line_Edit::qt_metacast(const char *_clname)
 {
-    if (!_clname) return 0;
-    if (!strcmp(_clname, qt_meta_stringdata_Drag_Drop_Line_Edit))
-        return static_cast<void*>(const_cast< Drag_Drop_Line_Edit*>(this));
+    if (!_clname) return nullptr;
+    if (!strcmp(_clname, qt_meta_stringdata_Drag_Drop_Line_Edit.stringdata0))
+        return static_cast<void*>(this);
     return Tooltip_Line_Edit::qt_metacast(_clname);
 }
 
 int Drag_Drop_Line_Edit::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
 {
     _id = Tooltip_Line_Edit::qt_metacall(_c, _id, _a);
-    if (_id < 0)
-        return _id;
     return _id;
 }
+QT_WARNING_POP
 QT_END_MOC_NAMESPACE
