@@ -1,25 +1,49 @@
 /****************************************************************************
 ** Meta object code from reading C++ file 'ttlineedit.h'
 **
-** Created by: The Qt Meta Object Compiler version 63 (Qt 4.8.7)
+** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
 
-#include "../../src/ttfautohint-1.8.1/frontend/ttlineedit.h"
+#include "../../src/ttfautohint-1.8.3/frontend/ttlineedit.h"
+#include <QtCore/qbytearray.h>
+#include <QtCore/qmetatype.h>
 #if !defined(Q_MOC_OUTPUT_REVISION)
 #error "The header file 'ttlineedit.h' doesn't include <QObject>."
-#elif Q_MOC_OUTPUT_REVISION != 63
-#error "This file was generated using the moc from 4.8.7. It"
+#elif Q_MOC_OUTPUT_REVISION != 67
+#error "This file was generated using the moc from 5.9.4. It"
 #error "cannot be used with the include files from this version of Qt."
 #error "(The moc has changed too much.)"
 #endif
 
 QT_BEGIN_MOC_NAMESPACE
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
+struct qt_meta_stringdata_Tooltip_Line_Edit_t {
+    QByteArrayData data[3];
+    char stringdata0[34];
+};
+#define QT_MOC_LITERAL(idx, ofs, len) \
+    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
+    qptrdiff(offsetof(qt_meta_stringdata_Tooltip_Line_Edit_t, stringdata0) + ofs \
+        - idx * sizeof(QByteArrayData)) \
+    )
+static const qt_meta_stringdata_Tooltip_Line_Edit_t qt_meta_stringdata_Tooltip_Line_Edit = {
+    {
+QT_MOC_LITERAL(0, 0, 17), // "Tooltip_Line_Edit"
+QT_MOC_LITERAL(1, 18, 14), // "change_tooltip"
+QT_MOC_LITERAL(2, 33, 0) // ""
+
+    },
+    "Tooltip_Line_Edit\0change_tooltip\0"
+};
+#undef QT_MOC_LITERAL
+
 static const uint qt_meta_data_Tooltip_Line_Edit[] = {
 
  // content:
-       6,       // revision
+       7,       // revision
        0,       // classname
        0,    0, // classinfo
        1,   14, // methods
@@ -29,21 +53,20 @@ static const uint qt_meta_data_Tooltip_Line_Edit[] = {
        0,       // flags
        0,       // signalCount
 
- // slots: signature, parameters, type, tag, flags
-      19,   18,   18,   18, 0x0a,
+ // slots: name, argc, parameters, tag, flags
+       1,    1,   19,    2, 0x0a /* Public */,
+
+ // slots: parameters
+    QMetaType::Void, QMetaType::QString,    2,
 
        0        // eod
 };
 
-static const char qt_meta_stringdata_Tooltip_Line_Edit[] = {
-    "Tooltip_Line_Edit\0\0change_tooltip(QString)\0"
-};
-
 void Tooltip_Line_Edit::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
 {
     if (_c == QMetaObject::InvokeMetaMethod) {
-        Q_ASSERT(staticMetaObject.cast(_o));
         Tooltip_Line_Edit *_t = static_cast<Tooltip_Line_Edit *>(_o);
+        Q_UNUSED(_t)
         switch (_id) {
         case 0: _t->change_tooltip((*reinterpret_cast< QString(*)>(_a[1]))); break;
         default: ;
@@ -51,29 +74,22 @@ void Tooltip_Line_Edit::qt_static_metacall(QObject *_o, QMetaObject::Call _c, in
     }
 }
 
-const QMetaObjectExtraData Tooltip_Line_Edit::staticMetaObjectExtraData = {
-    0,  qt_static_metacall 
-};
-
 const QMetaObject Tooltip_Line_Edit::staticMetaObject = {
-    { &QLineEdit::staticMetaObject, qt_meta_stringdata_Tooltip_Line_Edit,
-      qt_meta_data_Tooltip_Line_Edit, &staticMetaObjectExtraData }
+    { &QLineEdit::staticMetaObject, qt_meta_stringdata_Tooltip_Line_Edit.data,
+      qt_meta_data_Tooltip_Line_Edit,  qt_static_metacall, nullptr, nullptr}
 };
 
-#ifdef Q_NO_DATA_RELOCATION
-const QMetaObject &Tooltip_Line_Edit::getStaticMetaObject() { return staticMetaObject; }
-#endif //Q_NO_DATA_RELOCATION
 
 const QMetaObject *Tooltip_Line_Edit::metaObject() const
 {
-    return QObject::d_ptr->metaObject ? QObject::d_ptr->metaObject : &staticMetaObject;
+    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
 }
 
 void *Tooltip_Line_Edit::qt_metacast(const char *_clname)
 {
-    if (!_clname) return 0;
-    if (!strcmp(_clname, qt_meta_stringdata_Tooltip_Line_Edit))
-        return static_cast<void*>(const_cast< Tooltip_Line_Edit*>(this));
+    if (!_clname) return nullptr;
+    if (!strcmp(_clname, qt_meta_stringdata_Tooltip_Line_Edit.stringdata0))
+        return static_cast<void*>(this);
     return QLineEdit::qt_metacast(_clname);
 }
 
@@ -86,7 +102,12 @@ int Tooltip_Line_Edit::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
         if (_id < 1)
             qt_static_metacall(this, _c, _id, _a);
         _id -= 1;
+    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
+        if (_id < 1)
+            *reinterpret_cast<int*>(_a[0]) = -1;
+        _id -= 1;
     }
     return _id;
 }
+QT_WARNING_POP
 QT_END_MOC_NAMESPACE
